Table table;
int row, col;
String url;
String url2;

void loadData(){
    //load Glogbal Capture Production data
    GCP = new Yield[9];
    table = loadTable("global capture.csv", "header");
    row = table.getRowCount(); 
    col = table.getColumnCount();
    for(int i = 0, y = 0; i < row; i+=7){
        //global capture data
        int j = 0, z = 0;
        String land = table.getString(i, j);
        String ocean = table.getString(i, j+1);
        int[] aquaticP = new int[DURATION];
        int[] crustacean  = new int[DURATION];
        int[] freshwaterF = new int[DURATION];
        int[] diadromousF = new int[DURATION];
        int[] marineF = new int[DURATION];
        int[] molluscs = new int[DURATION];
        int[] aquaticM = new int[DURATION]; 
        for(j = 5; j < col; j +=2, z++){
            aquaticP[z] = table.getInt(i, j);
            crustacean[z] = table.getInt(i+1, j);
            freshwaterF[z] = table.getInt(i+2, j);
            diadromousF[z] = table.getInt(i+3, j);
            marineF[z] = table.getInt(i+4, j);
            molluscs[z] = table.getInt(i+5, j);
            aquaticM[z] = table.getInt(i+6, j);
        }
        GCP[y] = new Yield(land, ocean, aquaticP, crustacean, freshwaterF, diadromousF,
                           marineF, molluscs, aquaticM);
        y++;
    }
    table.clearRows();
    
    //load Glogbal Sea Level data
    sL = new SeaLevel[9];

    //Atlantic Ocean and adjacent seas -- 1
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/258.rlrdata"; //alternative data, but not contigent
    url2 = "http://www.psmsl.org/data/obtaining/rlr.annual.data/2171.rlrdata"; // only start from 2006
    sL[0] = new SeaLevel(getSeaLevel(url, url2));
    
    //Pacific Ocean -- 2
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/155.rlrdata";
    sL[1] = new SeaLevel(getSeaLevel(url));
    
    //Africa Atlantic Ocean and adjacent seas -- 3
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/303.rlrdata"; //   have 85-89
    url2 = "http://www.psmsl.org/data/obtaining/rlr.annual.data/565.rlrdata"; //92 -- 14
    sL[2] = new SeaLevel(getSeaLevel(url, url2));
    
    //Americas Atlantic Ocean and adjacent seas -- 4
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/224.rlrdata";
    sL[3] = new SeaLevel(getSeaLevel(url));
    
    //Americas Pacific Ocean -- 5
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/1352.rlrdata";
    sL[4] = new SeaLevel(getSeaLevel(url));
    
    //Asia Pacific -- 6
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/1390.rlrdata";
    sL[5] = new SeaLevel(getSeaLevel(url));
    
    //Europe Atlantic Ocean and adjacent seas -- 7
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/202.rlrdata"; 
    sL[6] = new SeaLevel(getSeaLevel(url));
    
    //Europe Pacific Ocean -- 8
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/824.rlrdata";
    sL[7] = new SeaLevel(getSeaLevel(url));
    
    //Oceania Pacific Ocean -- 9
    url = "http://www.psmsl.org/data/obtaining/rlr.annual.data/637.rlrdata";
    sL[8] = new SeaLevel(getSeaLevel(url));
  
  
    //load global temperature
    gT = new GlobalTemprature("http://data.giss.nasa.gov/gistemp/tabledata_v3/ZonAnn.Ts+dSST.txt");

}



public int[] getSeaLevel(String url){
    int[] seaLevel = new int[YEAR];
    
    String lines[] = loadStrings(url);
    for(int i = 0, y = 0; i < lines.length; i++){
      if(lines[i] != null){
        int level, year;
        level = Integer.parseInt(lines[i].substring(8, 12));
        year = Integer.parseInt(lines[i].substring(1, 5));
        if(year >= 1985 && y==year-1985){
          if(level>5000 && level<8000){
            seaLevel[y] = level;
          }else{
            seaLevel[y] = seaLevel[y-1];
          }
          y++;
        }
      }
      if(y == seaLevel.length){
        break;
      }
    }
    return seaLevel;
}

public int[] getSeaLevel(String url, String url2){
    int[] seaLevel = new int[YEAR];
    
    String lines[] = loadStrings(url);
    for(int i = 0; i < lines.length; i++){
        if(lines[i] != null){
            int level, year;
            level = Integer.parseInt(lines[i].substring(8, 12));
            year = Integer.parseInt(lines[i].substring(1, 5));
            if(year >= 1985 && year <= 2013 && level>5000 && level<8000){
                seaLevel[year-1985] = level; 
            }
        } 
    }
    lines = loadStrings(url2);
    for(int i = 0; i < lines.length; i++){
        if(lines[i] != null){
            int level, year;
            level = Integer.parseInt(lines[i].substring(8, 12));
            year = Integer.parseInt(lines[i].substring(1, 5));
            if(year >= 1985 && year <= 2013 && level>5000 && level<8000){
                seaLevel[year-1985] = level; 
            }
        } 
    }
    
    for(int i = 0; i < seaLevel.length; i++){
        if(seaLevel[i] == 0 || seaLevel[i]<5001 || seaLevel[i]>7999){
            seaLevel[i] = seaLevel[i-1];
        }
    }
 
    return seaLevel;
}


void printData(){
    println("Global Capture Production");
    for(int i = 0; i<GCP.length; i++){
      println("Area: "+ i);
      for(int j = 0; j < GCP[i].marineF.length; j++){
        println("Year: " + (j+1985) + "   value: " + GCP[i].marineF[j]);
      }
    }
  
    println();  
    println("Sea Level:");
    for(int i = 0; i<sL.length; i++){
      println("Area: "+ i);
      for(int j = 0; j < sL[i].seaLevel.length; j++){
        println("Year: " + (j+1985) + "   value: " + sL[i].seaLevel[j]);
      }
    }
    println();
    println("Global Temperature");
    for(int i = 0; i<gT.temperature.length; i++){
        println("Year: " + (i+1985) + "   value: " + gT.temperature[i]);
    }
  
}